@@ -221,6 +221,7 @@ RESERVED = MatchFirst([
     OVER,
     PARTITION,
     PRIMARY,
+    PIVOT,
     QUALIFY,
     REFERENCES,
     RIGHT,
@@ -233,6 +234,7 @@ RESERVED = MatchFirst([
     UNION,
     UNIQUE,
     UNNEST,
+    UNPIVOT,
     USING,
     WHEN,
     WHERE,
