@@ -67,6 +67,7 @@ BIGDECIMAL = Group(keyword("bigdecimal")("op")) / to_json_call
 FLOAT = Group(keyword("float")("op") + Optional(flag("unsigned"))) / to_json_call
 GEOMETRY = Group(keyword("geometry")("op")) / to_json_call
 INTEGER = Group(keyword("integer")("op") + Optional(flag("unsigned"))) / to_json_call
+INTERVAL = Group(keyword("interval")("op")) / to_json_call
 INT = (keyword("int")("op") + _size + Optional(flag("unsigned"))) / to_json_call
 INT32 = Group(keyword("int32")("op")) / to_json_call
 INT64 = Group(keyword("int64")("op")) / to_json_call
@@ -154,6 +155,7 @@ simple_types << MatchFirst([
     GEOMETRY,
     MAP_TYPE,
     INTEGER,
+    INTERVAL,
     INT,
     INT32,
     INT64,
